.. _sponsors:

********
Sponsors
********

The Mopidy project would like to thank the following sponsors for supporting
the project.


Rackspace
=========

`Rackspace <http://www.rackspace.com/>`_ lets Mopidy use their hosting services
for free. We use their services for the following sites:

- Hosting of the APT package repository at https://apt.mopidy.com.

- Hosting of the Discourse forum at https://discuss.mopidy.com.

- Mailgun for sending emails from the Discourse forum.

- Hosting of the Jenkins CI server at https://ci.mopidy.com.

- Hosting of a Linux worker for https://ci.mopidy.com.

- Hosting of a Windows worker for https://ci.mopidy.com.

- CDN hosting at http://dl.mopidy.com, which is used to distribute Pi Musicbox
  images.


GlobalSign
==========

`GlobalSign <https://www.globalsign.com/>`_ provides Mopidy with a free
wildcard SSL certificate for mopidy.com, which we use to secure access to all
our web sites.
